==> fvm-1.3.0-dev.2.tar.gz: test/flutter_project_test.dart <==
@Timeout(Duration(minutes: 5))
import 'package:test/test.dart';

import 'package:fvm/fvm.dart';

import 'test_helpers.dart';

void main() {
  setUpAll(fvmSetUpAll);
  tearDownAll(fvmTearDownAll);
  group('Flutter Projects', () {
    test('Can find Flutter Project', () async {
      try {
        // final flutterProject =
        await FlutterProjectRepo.findAncestor(dir: kFlutterAppDir);
        final dartPackage =
            await FlutterProjectRepo.findAncestor(dir: kDartPackageDir);
        final emptyProject =
            await FlutterProjectRepo.findAncestor(dir: kEmptyDir);

        expect(dartPackage != null, true);
        expect(emptyProject != null, true);
        // expect(flutterProject != null, true);
        // expect(flutterProject.name, 'flutter_app');
        // expect(flutterProject.projectDir.path, kFlutterAppDir.path);

        // expect(await FlutterProjectRepo.isFlutterProject(kFlutterAppDir), true);
        // expect(
        //     await FlutterProjectRepo.isFlutterProject(kDartPackageDir), false);
        // expect(await FlutterProjectRepo.isFlutterProject(kEmptyDir), false);
      } on Exception catch (e) {
        fail('Exception thrown, $e');
      }
    });

    test('Can set SDK version on Flutter Project', () async {
      try {
        final flutterProject = await FlutterProjectRepo.findAncestor();

        final flutterProjectVersion = await getRandomFlutterVersion();

        await FlutterProjectRepo.pinVersion(
          flutterProject,
          flutterProjectVersion,
        );

        expect(flutterProject.pinnedVersion, flutterProjectVersion);
      } on Exception catch (e) {
        fail('Exception thrown, $e');
      }
    });

    test('Can find Flutter Project', () async {
      final projects =
          await FlutterProjectRepo.scanDirectory(rootDir: kTestAssetsDir);
      expect(projects.length, 1);
    });
  });
}

==> fvm-1.3.1.tar.gz: test/flutter_project_test.dart <==
@Timeout(Duration(minutes: 5))
import 'package:test/test.dart';

import 'package:fvm/fvm.dart';

import 'test_helpers.dart';

void main() {
  setUpAll(fvmSetUpAll);
  tearDownAll(fvmTearDownAll);
  group('Flutter Projects', () {
    test('Can find Flutter Project', () async {
      try {
        final flutterProject =
            await FlutterProjectRepo.findAncestor(dir: kFlutterAppDir);
        final dartPackage =
            await FlutterProjectRepo.findAncestor(dir: kDartPackageDir);
        final emptyProject =
            await FlutterProjectRepo.findAncestor(dir: kEmptyDir);

        expect(dartPackage != null, true);
        expect(emptyProject != null, true);
        expect(flutterProject != null, true);
        expect(flutterProject.name, 'flutter_app');
        expect(flutterProject.projectDir.path, kFlutterAppDir.path);

        expect(flutterProject.isFlutterProject, true);
        expect(dartPackage.isFlutterProject, false);
        expect(emptyProject.isFlutterProject, false);
      } on Exception catch (e) {
        fail('Exception thrown, $e');
      }
    });

    test('Can set SDK version on Flutter Project', () async {
      try {
        final flutterProject = await FlutterProjectRepo.findAncestor();

        final flutterProjectVersion = await getRandomFlutterVersion();

        await FlutterProjectRepo.pinVersion(
          flutterProject,
          flutterProjectVersion,
        );

        expect(flutterProject.pinnedVersion, flutterProjectVersion);
      } on Exception catch (e) {
        fail('Exception thrown, $e');
      }
    });

    test('Can find Flutter Project', () async {
      final projects =
          await FlutterProjectRepo.scanDirectory(rootDir: kTestAssetsDir);
      expect(projects.length, 1);
    });
  });
}
